package com.ruoyi.rc.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.rc.mapper.TMeetingMapper;
import com.ruoyi.rc.domain.TMeeting;
import com.ruoyi.rc.service.ITMeetingService;

/**
 * 会议Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@Service
public class TMeetingServiceImpl implements ITMeetingService 
{
    @Autowired
    private TMeetingMapper tMeetingMapper;

    /**
     * 查询会议
     * 
     * @param id 会议主键
     * @return 会议
     */
    @Override
    public TMeeting selectTMeetingById(Long id)
    {
        return tMeetingMapper.selectTMeetingById(id);
    }

    /**
     * 查询会议列表
     * 
     * @param tMeeting 会议
     * @return 会议
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<TMeeting> selectTMeetingList(TMeeting tMeeting)
    {
        return tMeetingMapper.selectTMeetingList(tMeeting);
    }

    /**
     * 新增会议
     * 
     * @param tMeeting 会议
     * @return 结果
     */
    @Override
    public int insertTMeeting(TMeeting tMeeting)
    {
        return tMeetingMapper.insertTMeeting(tMeeting);
    }

    /**
     * 修改会议
     * 
     * @param tMeeting 会议
     * @return 结果
     */
    @Override
    public int updateTMeeting(TMeeting tMeeting)
    {
        return tMeetingMapper.updateTMeeting(tMeeting);
    }

    /**
     * 批量删除会议
     * 
     * @param ids 需要删除的会议主键
     * @return 结果
     */
    @Override
    public int deleteTMeetingByIds(Long[] ids)
    {
        return tMeetingMapper.deleteTMeetingByIds(ids);
    }

    /**
     * 删除会议信息
     * 
     * @param id 会议主键
     * @return 结果
     */
    @Override
    public int deleteTMeetingById(Long id)
    {
        return tMeetingMapper.deleteTMeetingById(id);
    }
}
